Title: [128426] trunk/Source/WebKit/chromium
Revision
128426
Author
[email protected]
Date
2012-09-13 01:41:21 -0700 (Thu, 13 Sep 2012)

Log Message

Unreviewed, rolling out r128409.
http://trac.webkit.org/changeset/128409
https://bugs.webkit.org/show_bug.cgi?id=96622

It broke Chromium browser_tests (Requested by tkent on
#webkit).

Patch by Sheriff Bot <[email protected]> on 2012-09-13

* src/WebFrameImpl.cpp:
(WebKit::WebFrameImpl::scopeStringMatches):
(WebKit::WebFrameImpl::shouldScopeMatches):

Modified Paths

Diff

Modified: trunk/Source/WebKit/chromium/ChangeLog (128425 => 128426)


--- trunk/Source/WebKit/chromium/ChangeLog	2012-09-13 08:40:00 UTC (rev 128425)
+++ trunk/Source/WebKit/chromium/ChangeLog	2012-09-13 08:41:21 UTC (rev 128426)
@@ -1,3 +1,16 @@
+2012-09-13  Sheriff Bot  <[email protected]>
+
+        Unreviewed, rolling out r128409.
+        http://trac.webkit.org/changeset/128409
+        https://bugs.webkit.org/show_bug.cgi?id=96622
+
+        It broke Chromium browser_tests (Requested by tkent on
+        #webkit).
+
+        * src/WebFrameImpl.cpp:
+        (WebKit::WebFrameImpl::scopeStringMatches):
+        (WebKit::WebFrameImpl::shouldScopeMatches):
+
 2012-09-13  Taiju Tsuiki  <[email protected]>
 
         Check if WorkerContext is terminated in WebWorkerClientImple::openFileSystem call.

Modified: trunk/Source/WebKit/chromium/src/WebFrameImpl.cpp (128425 => 128426)


--- trunk/Source/WebKit/chromium/src/WebFrameImpl.cpp	2012-09-13 08:40:00 UTC (rev 128425)
+++ trunk/Source/WebKit/chromium/src/WebFrameImpl.cpp	2012-09-13 08:41:21 UTC (rev 128426)
@@ -1779,10 +1779,8 @@
                                       const WebFindOptions& options,
                                       bool reset)
 {
-    if (!shouldScopeMatches(searchText)) {
-        increaseMatchCount(0, identifier);
+    if (!shouldScopeMatches(searchText))
         return;
-    }
 
     WebFrameImpl* mainFrameImpl = viewImpl()->mainFrameImpl();
 
@@ -2614,9 +2612,9 @@
 
 bool WebFrameImpl::shouldScopeMatches(const String& searchText)
 {
     // Don't scope if we can't find a frame or a view.
     // The user may have closed the tab/application, so abort.
-    if (!frame() || !frame()->view())
+    if (!frame() || !frame()->view() || !hasVisibleContent())
         return false;
 
     ASSERT(frame()->document() && frame()->view());
@@ -2614,9 +2612,9 @@
 bool WebFrameImpl::shouldScopeMatches(const String& searchText)
 {
-    // Don't scope if we can't find a frame or a view.
+    // Don't scope if we can't find a frame or a view or if the frame is not visible.
     // The user may have closed the tab/application, so abort.
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to